<#	
	.NOTES
	===========================================================================
	 Created with: 	SAPIEN Technologies, Inc., PowerShell Studio 2019 v5.6.161
	 Created on:   	4/2/2019 6:07 PM
	 Created by:   	max_t
	 Organization: 	SAPIEN Technologies, Inc.
	 Filename:  WriteProgressSample02.ps1   	
	===========================================================================
	.DESCRIPTION
		Sample function showcasing multiple Write-Progress bar while collecting Event
		information.

."C:\Users\xxxx\Documents\SAPIEN\Scripts\WriteProgressSamples\WriteProgressSample02.ps1"

#>

function Get-MyApplicationEvent
{[CmdletBinding()]
	Param (
		[string]$COMPUTERNAME = "$env:COMPUTERNAME",
		[ValidateRange(1,100)] 
		[int]$NumEntries = '100'
	)
	BEGIN
	{
		Clear-Host;
		
		Write-Host "Getting Application Events in Progress";
		Start-Sleep -Seconds 2;
		
		## - Get Envent log entries with the assigned number of entries less than 101: 
		$EventLog = Get-EventLog -LogName Application -Newest $NumEntries -ComputerName $ComputerName;
		
	}
	PROCESS
	{
		## - Write-Progress distiguished ID:
		$Id = 1;
		
		## - Initialize variables:
		$EntryCount = 0; $AppLogEntries = $null;
		
		## - Foreach-loop to collect EventLog entries and build the PSObject variable:
		$EventLog | foreach {
			[System.Array]$AppLogEntries += $_ | `
			Select-Object @{ label = 'Computer'; Expression = { $ComputerName } }, `
						  Source, `
						  TimeGenerated, `
						  Message, `
						  InstanceId;
			
			## - Display Progress Bar:
			Write-Progress -Id $Id `
			-Activity "Total Entries Found: $($EventLog.Count)" `
			-PercentComplete (($EntryCount/$EventLog.Count)*100)`
			-Status "Build PSObject Results - [$($EntryCount)]";
			
			## - Add delay to show progress bar:
			Start-Sleep -Milliseconds 100;
			
			## - Increment entry counter variable:
			$EntryCount++
		};
	}
	END
	{
		## - Display Eventlog collected entries stored in the PSObject variable:
		$AppLogEntries;
	}
}; Get-MyApplicationEvent 
